@@ -9,7 +9,7 @@ sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 import unittest
 import json
 
-from youtube_dl.utils import compat_urllib_parse
+from yt_dlp.utils import compat_urllib_parse
 from youtubedlapi_server_infusiblecoder.app import app
 from youtubedlapi_server_infusiblecoder.version import __version__
 
@@ -28,7 +28,7 @@ class ServerTest(unittest.TestCase):
 
     def test_TED(self):
         """Test video (TED talk)"""
-        test_url = "http://www.ted.com/talks/dan_dennett_on_our_consciousness.html"
+        test_url = "https://www.ted.com/talks/chloe_valdary_how_love_can_help_repair_social_inequality"
         info = self.get_video_info(test_url)
         self.assertEqual(info["url"], test_url)
         video_info = info['info']
@@ -39,7 +39,7 @@ class ServerTest(unittest.TestCase):
 
     def test_Vimeo(self):
         """Test Vimeo support"""
-        test_url = 'http://vimeo.com/56015672'
+        test_url = 'https://vimeo.com/120061340'
         info = self.get_video_info(test_url)
         self.assertEqual(info["url"], test_url)
 
@@ -50,13 +50,13 @@ class ServerTest(unittest.TestCase):
         ids = set(v['id'] for v in info['info']['entries'])
         self.assertEqual(ids, {'_DiEbmg3lU8'})
 
-        test_url = 'https://www.youtube.com/watch?v=QRS8MkLhQmM'
+        test_url = 'https://www.youtube.com/watch?v=eiBVlxxu3so'
         video_info = self.get_video_info(test_url, writesubtitles='true', subtitleslangs='it,fr')['info']
         requested_subs = video_info['requested_subtitles']
         self.assertEqual(set(requested_subs.keys()), {'it', 'fr'})
 
     def test_flatten(self):
-        test_url = 'http://vimeo.com/56015672'
+        test_url = 'https://vimeo.com/120061340'
         info = self.get_video_info(test_url, flatten=True)
         videos = info['videos']
         video_info = videos[0]
