@@ -28,7 +28,7 @@ def get_videos(url, extra_params):
     ydl_params = {
         'format': 'best',
         'cachedir': False,
-        'logger': current_app.logger.getChild('yt-dlp'),
+        'logger': current_app.logger.getChild('youtube-dl'),
     }
     ydl_params.update(extra_params)
     ydl = SimpleYDL(ydl_params)
@@ -176,8 +176,8 @@ def list_extractors():
 @set_access_control
 def version():
     result = {
-        'yt-dlp': '2022.3.8.2',
-        'youtubedlapi-server-infusiblecoder': __version__,
+        'youtube-dl': '2022.8.19',
+        'youtube-dl-api-server': __version__,
     }
     return jsonify(result)
 
